@@ -1,5 +1,5 @@
 import tensorflow as tf
-from ..layers.layers import TransLayer
+from ..layers.layers import TransformLayer
 
 class RucModel(tf.keras.models.Model):
 
